[−][src]Enum unicode_types::lepcha::Lepcha
An enum to represent all characters in the Lepcha block.
Variants
LetterKa\u{1c00}: 'ᰀ'
LetterKla\u{1c01}: 'ᰁ'
LetterKha\u{1c02}: 'ᰂ'
LetterGa\u{1c03}: 'ᰃ'
LetterGla\u{1c04}: 'ᰄ'
LetterNga\u{1c05}: 'ᰅ'
LetterCa\u{1c06}: 'ᰆ'
LetterCha\u{1c07}: 'ᰇ'
LetterJa\u{1c08}: 'ᰈ'
LetterNya\u{1c09}: 'ᰉ'
LetterTa\u{1c0a}: 'ᰊ'
LetterTha\u{1c0b}: 'ᰋ'
LetterDa\u{1c0c}: 'ᰌ'
LetterNa\u{1c0d}: 'ᰍ'
LetterPa\u{1c0e}: 'ᰎ'
LetterPla\u{1c0f}: 'ᰏ'
LetterPha\u{1c10}: 'ᰐ'
LetterFa\u{1c11}: 'ᰑ'
LetterFla\u{1c12}: 'ᰒ'
LetterBa\u{1c13}: 'ᰓ'
LetterBla\u{1c14}: 'ᰔ'
LetterMa\u{1c15}: 'ᰕ'
LetterMla\u{1c16}: 'ᰖ'
LetterTsa\u{1c17}: 'ᰗ'
LetterTsha\u{1c18}: 'ᰘ'
LetterDza\u{1c19}: 'ᰙ'
LetterYa\u{1c1a}: 'ᰚ'
LetterRa\u{1c1b}: 'ᰛ'
LetterLa\u{1c1c}: 'ᰜ'
LetterHa\u{1c1d}: 'ᰝ'
LetterHla\u{1c1e}: 'ᰞ'
LetterVa\u{1c1f}: 'ᰟ'
LetterSa\u{1c20}: 'ᰠ'
LetterSha\u{1c21}: 'ᰡ'
LetterWa\u{1c22}: 'ᰢ'
LetterA\u{1c23}: 'ᰣ'
SubjoinedLetterYa\u{1c24}: 'ᰤ'
SubjoinedLetterRa\u{1c25}: 'ᰥ'
VowelSignAa\u{1c26}: 'ᰦ'
VowelSignI\u{1c27}: 'ᰧ'
VowelSignO\u{1c28}: 'ᰨ'
VowelSignOo\u{1c29}: 'ᰩ'
VowelSignU\u{1c2a}: 'ᰪ'
VowelSignUu\u{1c2b}: 'ᰫ'
VowelSignE\u{1c2c}: 'ᰬ'
ConsonantSignK\u{1c2d}: 'ᰭ'
ConsonantSignM\u{1c2e}: 'ᰮ'
ConsonantSignL\u{1c2f}: 'ᰯ'
ConsonantSignN\u{1c30}: 'ᰰ'
ConsonantSignP\u{1c31}: 'ᰱ'
ConsonantSignR\u{1c32}: 'ᰲ'
ConsonantSignT\u{1c33}: 'ᰳ'
ConsonantSignNyinDashDo\u{1c34}: 'ᰴ'
ConsonantSignKang\u{1c35}: 'ᰵ'
SignRan\u{1c36}: 'ᰶ'
SignNukta\u{1c37}: '᰷'
PunctuationTaDashRol\u{1c3b}: '᰻'
PunctuationNyetThyoomTaDashRol\u{1c3c}: '᰼'
PunctuationCerDashWa\u{1c3d}: '᰽'
PunctuationTshookCerDashWa\u{1c3e}: '᰾'
PunctuationTshook\u{1c3f}: '᰿'
DigitZero\u{1c40}: '᱀'
DigitOne\u{1c41}: '᱁'
DigitTwo\u{1c42}: '᱂'
DigitThree\u{1c43}: '᱃'
DigitFour\u{1c44}: '᱄'
DigitFive\u{1c45}: '᱅'
DigitSix\u{1c46}: '᱆'
DigitSeven\u{1c47}: '᱇'
DigitEight\u{1c48}: '᱈'
DigitNine\u{1c49}: '᱉'
LetterTta\u{1c4d}: 'ᱍ'
LetterTtha\u{1c4e}: 'ᱎ'
Methods
impl Lepcha[src]
pub fn new() -> Self[src]
The character with the lowest index in this unicode block
pub fn name(&self) -> String[src]
The character's name, in sentence case